from ansys.fluent.core.generated.datamodel_242.preferences import (
    Root as preferences_root,
)
from ansys.fluent.core.generated.datamodel_242.workflow import Root as workflow_root
import ansys.fluent.core.generated.solver.settings_242 as settings_root
from ansys.fluent.core.generated.solver.tui_242 import main_menu
from ansys.fluent.core.systemcoupling import SystemCoupling

class Solver:
    @property
    def version(self): ...
    @property
    def tui(self) -> main_menu: ...
    @property
    def workflow(self) -> workflow_root: ...
    @property
    def system_coupling(self) -> SystemCoupling: ...
    @property
    def preferences(self) -> preferences_root: ...
    def read_case_lightweight(self, file_name: str): ...
    def read_case(self, file_name: str): ...
    def write_case(self, file_name: str): ...
    @property
    def settings(self) -> settings_root.root: ...
